@@ -4,13 +4,13 @@ package App::PDF::Link;
 
 # pdflink -- insert file links in PDF documents
 
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 
 # Author          : Johan Vromans
 # Created On      : Thu Sep 15 11:43:40 2016
 # Last Modified By: Johan Vromans
-# Last Modified On: Thu Feb 15 19:32:54 2018
-# Update Count    : 382
+# Last Modified On: Tue Feb  5 10:46:41 2019
+# Update Count    : 386
 # Status          : Unknown, Use with caution!
 
 ################ Common stuff ################
@@ -368,9 +368,10 @@ sub app_setup {
 	  'ident'		=> \$ident,
 	  'help|?'		=> \$help,
 	  'manual'		=> \$man,
-	  'verbose',
+	  'verbose|v',
 	  'trace',
 	  'debug',
+	  'version' => sub { app_ident(\*STDOUT); exit },
 	 ) )
     {
 	$pod2usage->(2);
